/*
	Copyright (c) 2021 Arsen Musayelyan

	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all
	copies or substantial portions of the Software.
*/

package scpt

import (
	"github.com/alecthomas/participle/lexer"
	"github.com/alecthomas/participle/lexer/stateful"
)

// Create custom stateful regex lexer
var scptLexer = lexer.Must(stateful.NewSimple([]stateful.Rule{
	{"Ident", `[a-zA-Z_]\w*`, nil},
	{"String", `"[^"]*"`, nil},
	{"Number", `(?:\d*\.)?\d+`, nil},
	{"Punct", `[-[!@$&(){}\|:;"',.?/]|]`, nil},
	{"Whitespace", `[ \t\r\n]+`, nil},
	{"Comment", `(###(.|\n)+###|#[^\n]+)`, nil},
	{"Operator", `(>=|<=|>|<|==|!=)|[-+*/^%]`, nil},
}))
